#
# spec file for package xplr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xplr
Version:        0.21.9
Release:        2.2
Summary:        TUI file explorer
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/sayanarijit/xplr
Source0:        https://github.com/sayanarijit/xplr/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        https://github.com/sayanarijit/xplr/releases/download/v%{version}/source.tar.gz.asc#/v%{version}.tar.gz.asc#/%{name}-%{version}.tar.gz.asc
Source4:        https://arijitbasu.in/gpg.txt#/%{name}.keyring
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  hicolor-icon-theme
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches}

%description
xplr is a terminal UI based file explorer for command-line utilities
that work with the file-system.

xplr integrates shell commands and GUI file managers and exposes a
scriptable, keyboard-controlled, real-time visual interface.

%prep
%autosetup -a1
sed -i 's/-- version = "0.0.0"/version = "%{version}"/' src/init.lua
# This conflicts with vendored cargo
rm .cargo/config

%build
%{cargo_build} --all-features

%install
%{cargo_install} --all-features

install -Dm644 -T \
    %{_builddir}/%{name}-%{version}/assets/desktop/%{name}.desktop \
    %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm644 -T \
    %{_builddir}/%{name}-%{version}/src/init.lua \
    %{buildroot}%{_sysconfdir}/%{name}/init.lua

for i in 128 16 32 64; do
    install -Dm644 "%{_builddir}/%{name}-%{version}/assets/icon/%{name}${i}.png" "%{buildroot}/%{_datadir}/icons/hicolor/${i}-${i}/apps/%{name}.png"
done

install -Dm644 "%{_builddir}/%{name}-%{version}/assets/icon/%{name}.svg" -t "%{buildroot}/%{_datadir}/icons/hicolor/scalable/apps"

%files
%license LICENSE
%doc CONTRIBUTING.md README.md RELEASE.md

%{_bindir}/%{name}
%{_datadir}/icons/*
%{_datadir}/applications/*

%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/init.lua

%changelog
* Tue Nov 19 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Reupload new vendor.tar.zst. Generated with new cargo_vendor passed with
  respect-lockfile
- Only build for Rust's tier 1 platforms
* Thu Jul 11 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove deprecated cargo_audit -- Now part of cargo_vendor
- Update to version 0.21.9:
  * Limit scroll padding dynamically based on screen size
  * Fixed crashing on small screen
* Thu May 23 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.21.8:
  * Added vim-like scrolling as the default scrolling method. Set
    xplr.config.general.paginated_scrolling = true to disable
  * Added xplr.config.general.scroll_padding config option to set the padding
    in vim-like scrolling
  * Fixed some color rendering issues
  * Added feature flag so that xplr can be built with system Lua
  * Fixed ScrollUpHalf behavior.
  * xplr.util.lscolor() won't return nil anymore.
  * Arguments passed to the custom dynamic layout Lua function will include
    scrolltop field.
  * Fixed node_type resolution for directories with . in their name
  * Dependency updates.
* Thu Mar 21 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.21.7:
  * Added new key bindings c and m in default mode to quickly copy and move files,
    without using the selection ops mode.
  * Added xplr.util.debug() to see and debug Lua values.
  * Fixed ScrollUpHalf operation.
  * Dependency and docs updates.
* Thu Feb 15 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- We need to always switch to newer versions so we use `cargo` instead of `rust+cargo`
* Tue Jan 30 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.21.5:
  * Added new messages to make it easier to jump between the deep level
  directories from history (as an alternative to runtime bookmarking).
  - PreviousVisitedDeepBranch
  - NextVisitedDeepBranch
  * New key bindings ( and ) bound to the new messages.
  * Added support for function keys upto F24.
  * Added selection count indicator in Input/Logs panel, so that selection
  panel can be hidden without losing the indicator.
  * Dependency updates.
* Sat Dec  2 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Disable updates. Seems crates are not happy with updating
- Revendor dependencies
* Fri Nov 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update vendored dependencies.
- Remove cargo_config. cargo_config file is now part of vendored tarball.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Thu Aug 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies.
- Always update vendored deps in _service.
- Add signature xplr-0.21.3.tar.gz.asc
* Thu Aug 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.21.3:
  * Fixed "Illegal format character q" error seen on non GNU (including macOS and BSD) systems
  * Fixed a UI issue causing lower priority styles being fully ignored
  * Press f1 to see the global help menu from any mode, without leaving the mode.
  * Current mode help menu will be displayed on top of the global help menu.
  * Added hook: on_selection_change.
  * Documentation improvements.
* Fri Jun  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Disable update of vendored deps
* Thu Jun  1 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.21.2:
  * Added CustomLayout, a new custom panel type to allow nesting other layouts inside a static or dynamic
    layout. This will allow switching between different layouts dynamically, without having to switch modes.
  * $LS_COLORS will have lesser priority than xplr.config.node_types.*.style.
  * Now, there's no default color set in xplr.config.node_types.*.style, so xplr will default to $LS_COLORS.
  * xplr -m now uses jf to render and pass messages. This allows for a more flexible template syntax.
  * xplr will now ask before delete.
  * For copy, move or symlink operations, xplr will ask what to do if a file with the same name exists.
  * CLI help menu improvements
  * Several fixes and improvements in documentation
* Mon May 15 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.21.1:
  * SelectAll and ToggleSelectAll (i.e. ctrl-a) in a new directory
    will extend, instead of replace, the existing selected paths.
  * Fixed a UI bug causing random characters to turn bold.
* Mon Feb 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies.
- Use zstd compression for vendored deps.
* Fri Jan 13 2023 Dirk Müller <dmueller@suse.com>
- update to v0.20.2:
  * Updated UI to be more light theme and NO_COLOR friendly.
  * Fixed creating files inside multiple subdirectories (e.g.
    foo/bar/test.txt) (thanks to @soryeigeton for reporting and help
    debugging).
  * Added new hooks (contribution by @emsquid).
  * on_mode_switch
  * on_layout_switch
* Sat Dec 17 2022 Dirk Müller <dmueller@suse.com>
- update to v0.20.1:
  * xplr shell will default to $SHELL, using bash as a fallback. oh-my-zsh
    users please add TRAPEXIT() { echoti rmkx; } in your .zshrc (see #499
    for more info).
  * (experiment) xplr will now display full-screen help menu in intermediate
    modes. Set xplr.config.modes.builtin[mode].layout = nil to disable. e.g.
    xplr.config.modes.builtin.create.layout = nil
  * Added new utility functions to work with json and yaml data.
  * xplr.util.from_json()
  * xplr.util.to_json()
  * xplr.util.from_yaml()
  * xplr.util.to_yaml()
  * Added new utility function xplr.util.version() to get the currently
    running binary version (semantic versioning fields).
  * Fixed displaying multispace characters (Japanese, Chinese...), thanks to
    @Elvyria for contributing to tui-input.
  * Fixed a bug causing the creation of a new directory
  * Minor UI updates.
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Verify signatures from public keyring by adding author's public pgp key.
* Wed Nov  9 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add default configuration in /etc/xplr/
* Thu Nov  3 2022 Jan Engelhardt <jengelh@inai.de>
- Remove marketing blether from descriptions.
* Wed Nov  2 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.20.0:
  * BREAKING: xplr shell (:!) will default to null (\0) delimited pipes, as
  opposed to newline (\n) delimited ones (i.e. will use Call0 instead of
  Call).
  * Use new messages for safer file path handling (\0 delimited):
  - Call0
  - CallSilently0
  - BashExec0
  - BashExecSilently0
  * Use new sub-commands for safer message passing:
  - -m FORMAT [ARGUMENT]... / --pipe-msg-in FORMAT [ARGUMENT]...
  - -M FORMAT [ARGUMENT]... / --print-msg-in FORMAT [ARGUMENT]...
  - Where FORMAT is a YAML string that may contain %%s, %%q and %%%%
  - placeholders and ARGUMENT is the value per placeholder. See init.lua
  * Use --vroot to isolate navigation of an xplr session inside a specific
  directory. Interaction still requires passing full path, and shell,
  lua functions etc still can access paths outside vroot.
  * Use the following messages to switch vroot at runtime, or the use key
  bindings available in the new builtin mode "vroot" (mapped to : v).
  - SetVroot
  - UnsetVroot
  - ToggleVroot
  - ResetVroot
  * Use $XPLR_INITIAL_PWD and Lua equivalent to implement workspace like
  features without using virtual root. Use keys gi to go to the initial
  working directory from anywhere.
  * Use the convenient xplr.util utility functions in your Lua function calls.
  See xplr.util API docs.
  * Improved CLI errors.
  * Finished documentation.
  * UI updates to handle newlines in path.
* Fri Oct 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies.
- Add _service file for OBS cargo vendor and cargo audit.
* Thu Oct 27 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for xplr 0.19.4
